@@ -1,8 +1,11 @@
-package Module::Signature;
-$Module::Signature::VERSION = '0.88';
-
 use 5.005;
 use strict;
+use warnings;
+
+# ABSTRACT: Module signature file manipulation
+package Module::Signature;
+our $VERSION = '0.92'; #VERSION
+
 use vars qw($VERSION $SIGNATURE @ISA @EXPORT_OK);
 use vars qw($Preamble $Cipher $Debug $Verbose $Timeout $AUTHOR);
 use vars qw($KeyServer $KeyServerPort $AutoKeyRetrieve $CanKeyRetrieve);
@@ -32,7 +35,7 @@ $AUTHOR         = $ENV{MODULE_SIGNATURE_AUTHOR};
 $SIGNATURE      = 'SIGNATURE';
 $Timeout        = $ENV{MODULE_SIGNATURE_TIMEOUT} || 3;
 $Verbose        = $ENV{MODULE_SIGNATURE_VERBOSE} || 0;
-$KeyServer      = $ENV{MODULE_SIGNATURE_KEYSERVER} || 'pool.sks-keyservers.net';
+$KeyServer      = $ENV{MODULE_SIGNATURE_KEYSERVER} || 'keyserver.ubuntu.com';
 $KeyServerPort  = $ENV{MODULE_SIGNATURE_KEYSERVERPORT} || '11371';
 $Cipher         = $ENV{MODULE_SIGNATURE_CIPHER} || 'SHA256';
 $Preamble       = << ".";
@@ -62,6 +65,7 @@ sub _cipher_map {
     for my $line (@lines) {
         last if $line eq '-----BEGIN PGP SIGNATURE-----';
         next if $line =~ /^---/ .. $line eq '';
+        next if $line eq '';
         my($cipher,$digest,$file) = split " ", $line, 3;
         return unless defined $file;
         $map{$file} = [$cipher, $digest];
@@ -325,22 +329,22 @@ sub _read_sigfile {
     my $signature = '';
     my $well_formed;
 
-    local *D;
-    open D, "< $sigfile" or die "Could not open $sigfile: $!";
+    my $sigfile_fh;
+    open ($sigfile_fh, '<', $sigfile) or die "Could not open $sigfile: $!";
 
-    if ($] >= 5.006 and <D> =~ /\r/) {
-        close D;
-        open D, '<', $sigfile or die "Could not open $sigfile: $!";
-        binmode D, ':crlf';
+    if ($] >= 5.006 and <$sigfile_fh> =~ /\r/) {
+        close $sigfile_fh;
+        open ($sigfile_fh, '<', $sigfile) or die "Could not open $sigfile: $!";
+        binmode $sigfile_fh, ':crlf';
     } else {
-        close D;
-        open D, "< $sigfile" or die "Could not open $sigfile: $!";
+        close $sigfile_fh;
+        open ($sigfile_fh, '<', $sigfile) or die "Could not open $sigfile: $!";
     }
 
     my $begin = "-----BEGIN PGP SIGNED MESSAGE-----\n";
     my $end = "-----END PGP SIGNATURE-----\n";
     my $found = 0;
-    while (<D>) {
+    while (<$sigfile_fh>) {
         if (1 .. ($_ eq $begin)) {
             if (!$found and /signed via the Module::Signature module, version ([0-9\.]+)\./) {
                 $found = 1;
@@ -375,18 +379,19 @@ sub _compare {
         warn Text::Diff::diff( \$str1, \$str2, { STYLE => 'Unified' } );
     }
     else {
-        local (*D, *S);
-        open S, "< $SIGNATURE" or die "Could not open $SIGNATURE: $!";
-        open D, "| diff -u --strip-trailing-cr $SIGNATURE -"
+        my $diff_fh;
+        my $signature_fh;
+        open ($signature_fh, '<', $SIGNATURE) or die "Could not open $SIGNATURE: $!";
+        open ($diff_fh, '|-', "diff -u --strip-trailing-cr $SIGNATURE -")
             or (warn "Could not call diff: $!", return SIGNATURE_MISMATCH);
-        while (<S>) {
-            print D $_ if (1 .. /^-----BEGIN PGP SIGNED MESSAGE-----/);
-            print D if (/^Hash: / .. /^$/);
+        while (<$signature_fh>) {
+            print $diff_fh $_ if (1 .. /^-----BEGIN PGP SIGNED MESSAGE-----/);
+            print $diff_fh if (/^Hash: / .. /^$/);
             next if (1 .. /^-----BEGIN PGP SIGNATURE/);
-            print D $str2, "-----BEGIN PGP SIGNATURE-----\n", $_ and last;
+            print $diff_fh $str2, "-----BEGIN PGP SIGNATURE-----\n", $_ and last;
         }
-        print D <S>;
-        close D;
+        print $diff_fh (<$signature_fh>);
+        close $diff_fh;
     }
 
     return SIGNATURE_MISMATCH;
@@ -404,7 +409,7 @@ sub sign {
         warn "==> Please correct your MANIFEST file and/or delete extra files. <==\n";
     }
 
-    if (!$overwrite and -e $SIGNATURE and -t STDIN) {
+    if (!$overwrite and -e $SIGNATURE and IO::Interactive::is_interactive()) {
         local $/ = "\n";
         print "$SIGNATURE already exists; overwrite [y/N]? ";
         return unless <STDIN> =~ /[Yy]/;
@@ -432,31 +437,33 @@ sub _sign_gpg {
 
     my $gpg = _which_gpg();
 
-    local *D;
+    my $gpg_fh;
     my $set_key = '';
     $set_key = qq{--default-key "$AUTHOR"} if($AUTHOR);
-    open D, "| $gpg $set_key --clearsign --openpgp --personal-digest-preferences RIPEMD160 >> $sigfile.tmp"
+    open ($gpg_fh, '|-', "$gpg $set_key --clearsign --openpgp --personal-digest-preferences RIPEMD160 >> $sigfile.tmp")
         or die "Could not call $gpg: $!";
-    print D $plaintext;
-    close D;
+    print $gpg_fh $plaintext;
+    close $gpg_fh;
 
     (-e "$sigfile.tmp" and -s "$sigfile.tmp") or do {
         unlink "$sigfile.tmp";
         die "Cannot find $sigfile.tmp, signing aborted.\n";
     };
 
-    open D, "< $sigfile.tmp" or die "Cannot open $sigfile.tmp: $!";
+    my $sigfile_tmp_fh;
+    open ($sigfile_tmp_fh, '<', "$sigfile.tmp") or die "Cannot open $sigfile.tmp: $!";
 
-    open S, "> $sigfile" or do {
+    my $sigfile_fh;
+    open ($sigfile_fh, '>', $sigfile) or do {
         unlink "$sigfile.tmp";
         die "Could not write to $sigfile: $!";
     };
 
-    print S $Preamble;
-    print S <D>;
+    print $sigfile_fh $Preamble;
+    print $sigfile_fh (<$sigfile_tmp_fh>);
 
-    close S;
-    close D;
+    close $sigfile_fh;
+    close $sigfile_tmp_fh;
 
     unlink("$sigfile.tmp");
 
@@ -537,11 +544,11 @@ sub _sign_crypt_openpgp {
         PassphraseCallback => \&Crypt::OpenPGP::_default_passphrase_cb,
     ) or die $pgp->errstr;
 
-    local *D;
-    open D, "> $sigfile" or die "Could not write to $sigfile: $!";
-    print D $Preamble;
-    print D $signature;
-    close D;
+    my $sigfile_fh;
+    open ($sigfile_fh, '>', $sigfile) or die "Could not write to $sigfile: $!";
+    print $sigfile_fh $Preamble;
+    print $sigfile_fh $signature;
+    close $sigfile_fh;
 
     require Crypt::OpenPGP::KeyServer;
     my $server = Crypt::OpenPGP::KeyServer->new(Server => $KeyServer);
@@ -588,13 +595,17 @@ sub _digest_object {
         or die "Malformed algorithm name: $algorithm (should match /\\w+\\d+/)";
 
     my $obj = eval { Digest->new($algorithm) } || eval {
-        require "Digest/$base.pm"; "Digest::$base"->new($variant)
+        my $module = "Digest/$base.pm";
+        require $module; "Digest::$base"->new($variant)
     } || eval {
-        require "Digest/$algorithm.pm"; "Digest::$algorithm"->new
+        my $module = "Digest/$algorithm.pm";
+        require $module; "Digest::$algorithm"->new
     } || eval {
-        require "Digest/$base/PurePerl.pm"; "Digest::$base\::PurePerl"->new($variant)
+        my $module = "Digest/$base/PurePerl.pm";
+        require $module; "Digest::$base\::PurePerl"->new($variant)
     } || eval {
-        require "Digest/$algorithm/PurePerl.pm"; "Digest::$algorithm\::PurePerl"->new
+        my $module = "Digest/$algorithm/PurePerl.pm";
+        require $module; "Digest::$algorithm\::PurePerl"->new
     } or do { eval {
         warn "Unknown cipher: $algorithm, please install Digest::$base, Digest::$base$variant, or Digest::$base\::PurePerl\n";
     } and return } or do {
@@ -639,19 +650,19 @@ sub _mkdigest_files {
             warn "No such file: $file\n" if $Verbose;
         }
         else {
-            local *F;
-            open F, "< $file" or die "Cannot open $file for reading: $!";
+            my $file_fh;
+            open( $file_fh, '<', $file ) or die "Cannot open $file for reading: $!";
             if ($LegacySigFile) {
                 if (-B $file) {
-                    binmode(F);
-                    $obj->addfile(*F);
+                    binmode($file_fh);
+                    $obj->addfile($file_fh);
                     $this_hexdigest = $obj->hexdigest;
                 }
                 else {
                     # Normalize by hand...
                     local $/;
-                    binmode(F);
-                    my $input = <F>;
+                    binmode($file_fh);
+                    my $input = <$file_fh>;
                 VERIFYLOOP: for my $eol ("","\015\012","\012") {
                         my $lax_input = $input;
                         if (! length $eol) {
@@ -678,8 +689,8 @@ sub _mkdigest_files {
                     }
                 }
             } else {
-                binmode(F, ((-B $file) ? ':raw' : ':crlf'));
-                $obj->addfile(*F);
+                binmode($file_fh, ((-B $file) ? ':raw' : ':crlf'));
+                $obj->addfile($file_fh);
                 $this_hexdigest = $obj->hexdigest;
             }
             $digest{$file} = [$this_cipher, $this_hexdigest];
@@ -694,12 +705,18 @@ sub _mkdigest_files {
 
 __END__
 
-=encoding utf8
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 Module::Signature - Module signature file manipulation
 
+=head1 VERSION
+
+version 0.92
+
 =head1 SYNOPSIS
 
 As a shell command:
@@ -751,6 +768,10 @@ SHA1 algorithm by default. SHA1 is now considered broken, and therefore
 module authors are strongly encouraged to regenerate their F<SIGNATURE>
 files. Users verifying old SHA1 signature files will receive a warning.
 
+=head1 NAME
+
+Module::Signature - Module signature file manipulation
+
 =head1 VARIABLES
 
 No package variables are exported by default.
@@ -974,7 +995,7 @@ You may add this code as F<t/0-signature.t> in your distribution tree:
                 "Next time around, consider install Module::Signature, ",
                 "so you can verify the integrity of this distribution.\n";
     }
-    elsif (!eval { require Socket; Socket::inet_aton('pool.sks-keyservers.net') }) {
+    elsif (!eval { require Socket; Socket::inet_aton('keyserver.ubuntu.com') }) {
         print "ok 1 # skip ",
                 "Cannot connect to the keyserver\n";
     }
@@ -997,7 +1018,7 @@ Also, if you prefer a more full-fledged testing package, and are
 willing to inflict the dependency of B<Module::Build> on your users,
 Iain Truskett's B<Test::Signature> might be a better choice.
 
-=cut
+=for Pod::Coverage sign verify
 
 =head1 SEE ALSO
 
@@ -1025,4 +1046,15 @@ This work is published from Taiwan.
 
 L<http://creativecommons.org/publicdomain/zero/1.0>
 
+=head1 AUTHOR
+
+Audrey Tang <cpan@audreyt.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2025 by waved.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
